@@ -27,11 +27,21 @@ sub Queue {
     return $self->TicketObj->QueueObj->Id;
 }
 
+sub TemplateContent {
+    my $self = shift;
+    return $self->TemplateObj->Content;
+}
+
 sub TemplateConfig {
     my $self = shift;
 
+    my ($content, $error) = $self->TemplateContent;
+    if (!defined($content)) {
+        return (undef, $error);
+    }
+
     my $Separator = '\|';
-    my @lines = split( /[\n\r]+/, $self->TemplateObj->Content );
+    my @lines = split( /[\n\r]+/, $content);
     my @results;
     for (@lines) {
         chomp;
@@ -47,14 +57,18 @@ sub TemplateConfig {
         $_ = '' for grep !defined, values %line;
         push @results, \%line;
     }
-    return @results;
+    return \@results;
 }
 
 sub Commit {
     my $self            = shift;
     return 1 unless $self->FirstAttachment;
 
-    for my $config ($self->TemplateConfig) {
+    my ($config_lines, $error) = $self->TemplateConfig;
+
+    return 0 if $error;
+
+    for my $config (@$config_lines) {
         my %config = %{$config};
         $RT::Logger->debug( "Looking to extract: "
                 . join( " ", map {"$_=$config{$_}"} sort keys %config ) );
@@ -88,11 +102,11 @@ sub Commit {
                 %config,
                 Callback    => sub {
                     my $content = shift;
-                    return 0 unless $content =~ /$config{Match}/m;
+                    return 0 unless $content =~ /($config{Match})/m;
                     $self->ProcessCF(
                         %config,
                         CustomField => $cf,
-                        Value       => $1 || $&,
+                        Value       => $2 || $1,
                     );
                     return 1;
                 }
